is_shape_array: Helper function to check if input is array of right...

Description Usage Arguments Value

View source: R/is_shape_array.R

Description

Helper function to check if input is array of right dimensions for shape analyses

Usage

1

Arguments

x

Value

TRUE or FALSE


iholzleitner/facefuns documentation built on March 19, 2021, 2:43 p.m.